==> nocc-1.8.1.tbz: www/nocc/lang/ar.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ar.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Arabic (العربية)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Meno25
 * @author Mohamed Hadrouj <mohamed.hadrouj@wanadoo.co.ma>
 * @author OsamaK
 */

$lang_locale = 'ar_AR.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'ءاسم المستخدم غير صحيح';
$err_passwd_empty = ' كلمة السر غير صحيحة. أعد المحاولة';
$alt_delete = 'ءازالة  الرسا ئل المختارة';
$alt_delete_one = 'ءازالة الرسالة';
$alt_new_msg = 'رسالة جديدة';
$alt_reply = 'ءاجاابة المرسل';
$alt_reply_all = 'ءاجاابة للجميع';
$alt_forward = 'تحويل';
$alt_next = 'تالي';
$alt_prev = 'سابق';
$title_next_page = 'الصفحة التالية';
$title_prev_page = 'الصفحة السابقة';
$title_next_msg = 'التالية';
$title_prev_msg = 'السابقة';
$html_on = 'مفعل';
$html_theme_label = 'السمة';
$html_welcome = 'مرحبا إلى %1$s';
$html_login = 'المستخدم';
$html_passwd = 'كلمة السر';
$html_submit = 'ءارسال';
$html_help = 'مساعدة';
$html_server = 'خادم';
$html_wrong = 'ءأسم المستخدم أو كلمة السر غير صحيحة';
$html_retry = 'أعد المحاولة';
$html_remember = 'تذكر الإعدادات';
$html_msgperpage_label = 'رسائل لكل صفحة';
$html_preferences = 'تفضيلات';
$html_full_name_label = 'الاسم الكامل';
$html_email_address_label = 'عنوان البريد الإلكتروني';
$html_hide_addresses = 'أخفِ العناوين';
$html_reply_to = 'رد إلى';
$html_use_signature = 'استخدم التوقيع';
$html_signature = 'توقيع';
$html_prefs_updated = 'حُدّثت التفضيلات';
$html_manage_filters_link = 'أدر مرشحات البريد الإلكتروني';
$html_use_graphical_smilies = 'استخدم الابتسامات الرسومية';
$html_colored_quotes = 'اقتباسات ملوّنة';
$html_send_html_mail = 'أرسل البريد بهيئة HTML';
$html_folders = 'مجلدات';
$html_folders_create_failed = 'تعذّر إنشاء المجلد!';
$html_folders_sub_failed = 'تعذّر الاشتراك بالمجلد!';
$html_folders_updated = 'حُدّثت المجلدات';
$html_folder_subscribe = 'اشترك ب';
$html_folder_rename = 'إعادة تسمية';
$html_folder_create = 'أنشئ مجلدا جديدا يسمّى';
$html_folder_remove = 'ألغِ الاشتراك من';
$html_folder_delete = 'حذف';
$html_folder_to = 'إلى';
$html_filter_remove = 'حذف';
$html_filter_body = 'جسم الرسالة';
$html_filter_subject = 'موضوع الرسالة';
$html_filter_to = 'حقل إلى';
$html_filter_cc = 'حقل النسخة';
$html_filter_from = 'حقل من';
$html_filter_change_tip = 'لتغيير مرشّح ببساطة اكتب فوقه.';
$html_filter_contains = 'يحتوي على';
$html_filter_name = 'اسم المرشح';
$html_filter_action = 'فعل المرشح';
$html_filter_moveto = 'نقل إلى';
$html_select_one = '--اختر واحدا--';
$html_and = 'و';
$html_new_msg_in = 'الرسائل الجديدة في';
$html_or = 'أو';
$html_move = 'نقل';
$html_copy = 'نسخ';
$html_messages_to = 'الرسالة المختارة إلى';
$html_gotopage = 'اذهب إلى الصفحة';
$html_gotofolder = 'اذهب إلى المجلد';
$html_other_folders = 'قائمة المجلدات';
$html_page = 'صفحة';
$html_of = 'ل';
$html_view_header = 'المقدمة';
$html_remove_header = 'ءاخفاء المقدمة';
$html_inbox = 'صندوق الرسائل';
$html_new_msg = 'رسالة جديدة';
$html_reply = 'ءاجابة';
$html_reply_short = 'رد';
$html_reply_all = 'ءاجابة للكل';
$html_forward = 'تحويل الرسالة ءالى';
$html_delete = 'ءازالة';
$html_new = 'جديد';
$html_mark = 'محو';
$html_att_label = 'ملف مرفق';
$html_atts_label = 'ملفات مرفقة';
$html_att_unknown = '[غير معروف]';
$html_attach = 'ءاضافة';
$html_attach_forget = '!يجب ءاضافة الملف قبل ءارسال الرسالة';
$html_attach_delete = 'ءازالة الملفات المختارة';
$html_sort_by = 'مرتبة حسب';
$html_sort = 'رتب';
$html_from = 'من';
$html_subject = 'الموضوع';
$html_date = 'التاريخ';
$html_sent = 'مرسل';
$html_wrote = 'كتب';
$html_size = 'الحجم';
$html_totalsize = 'الحجم الكلي';
$html_kb = 'كيلوبايت';
$html_mb = 'ميجابايت';
$html_gb = 'جيجابايت';
$html_bytes = 'بايت';
$html_filename = 'ملف';
$html_to = 'ءالى';
$html_cc = 'نسخة';
$html_bcc_label = 'نسخة مختبأة';
$html_nosubject = 'بدون موضوع';
$html_send = 'أرسل';
$html_cancel = 'ءالغاء';
$html_no_mail = 'ليست هناك أية رسالة';
$html_logout = 'ءانهاء الاءرتباط';
$html_msg = 'رسالة';
$html_msgs = 'رسائل';
$html_configuration = 'لم يُعد هذا الخادوم بشكل صحيح!';
$html_priority_label = 'أولوية';
$html_lowest = 'الأقل';
$html_low = 'أقل';
$html_normal = 'عادي';
$html_high = 'أعلى';
$html_highest = 'الأعلى';
$html_select = 'اختر';
$html_select_all = 'اعكس الاختيار';
$html_loading_image = 'تحميل الصورة';
$html_error_occurred = 'صودف خطأ';
$html_wrap_none = 'لا شيء';
$html_mark_as = 'علّم كـ';
$html_read = 'اقرأ';
$html_unread = 'غير مقروءة';
$html_encoding_label = 'ترميز المحارف';
$html_add = 'أضف';
$html_contacts = 'معارف %1$s';
$html_modify = 'عدل';
$html_back = 'رجوع';
$html_contact_add = 'أضف مراسلا جديدا';
$html_contact_mod = 'عدّل مراسلا';
$html_contact_first = 'الاسم الأول';
$html_contact_last = 'الاسم الأخير';
$html_contact_nick = 'الكنية';
$html_contact_mail = 'بريد';
$html_contact_list = 'قائمة معارف %1$s';
$html_contact_del = 'من قائمة المراسلين';
$html_contact_err1 = 'أقصى عدد للمراسلين هو';
$html_contact_err2 = 'لا تستطيع إضافة مراسل جديد';
$html_contact_err3 = 'لا تمتلك صلاحيات الوصول إلى قائمة المراسلين';
$html_del_msg = 'أأحذف الرسائل المختارة؟';
$html_down_mail = 'تنزيل';
$original_msg = '--  الرسالة الأصلية  --';
$to_empty = 'يجب ءاعطاء عنوان المرسل ءاليه !';
$html_images_warning = 'لأسباب أمنية، الصور البعيدة غير معروضة.';
$html_images_display = 'اعرض الصور';
$html_smtp_error_no_conn = 'تعذّر فتح اتصال SMTP';
$html_smtp_error_unexpected = 'رد SMTP غير متوقع:';
$lang_invalid_msg_num = 'عدد الرسائل السيئة';
$html_invalid_email_address = 'عنوان بريد إلكتروني غير صحيح';
$html_invalid_msg_per_page = 'عدد رسائل لكل صفحة غير صحيح';
$lang_err_send_delay = 'يتعين عليك الانتظار بين الرسالتين (%1$d seconds)';
$html_search = 'بحث';

==> nocc-1.8.3.tbz: www/nocc/lang/ar.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ar.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Arabic (العربية)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Meno25
 * @author Mohamed Hadrouj <mohamed.hadrouj@wanadoo.co.ma>
 * @author OsamaK
 */

$lang_locale = 'ar_AR.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'ءاسم المستخدم غير صحيح';
$err_passwd_empty = ' كلمة السر غير صحيحة. أعد المحاولة';
$alt_delete = 'ءازالة  الرسا ئل المختارة';
$alt_delete_one = 'ءازالة الرسالة';
$alt_new_msg = 'رسالة جديدة';
$alt_reply = 'ءاجاابة المرسل';
$alt_reply_all = 'ءاجاابة للجميع';
$alt_forward = 'تحويل';
$alt_next = 'تالي';
$alt_prev = 'سابق';
$title_next_page = 'الصفحة التالية';
$title_prev_page = 'الصفحة السابقة';
$title_next_msg = 'التالية';
$title_prev_msg = 'السابقة';
$html_theme_label = 'السمة:';
$html_welcome = 'مرحبا إلى %1$s';
$html_login = 'تسجيل الدخول';
$html_user_label = 'المستخدم';
$html_passwd_label = 'كلمة السر:';
$html_submit = 'ءارسال';
$html_help = 'مساعدة';
$html_server_label = 'الخادم:';
$html_wrong = 'ءأسم المستخدم أو كلمة السر غير صحيحة';
$html_retry = 'أعد المحاولة';
$html_remember = 'تذكر الإعدادات';
$html_lang_label = 'اللغة:';
$html_msgperpage_label = 'الرسائل لكل صفحة:';
$html_preferences = 'تفضيلات';
$html_full_name_label = 'الاسم الكامل:';
$html_email_address_label = 'عنوان البريد الإلكتروني:';
$html_hide_addresses = 'أخفِ العناوين';
$html_reply_to = 'رد إلى';
$html_use_signature = 'استخدم التوقيع';
$html_signature = 'توقيع';
$html_signature_label = 'التوقيع:';
$html_prefs_updated = 'حُدّثت التفضيلات';
$html_manage_folders_link = 'أدر مجلدات IMAP';
$html_manage_filters_link = 'أدر مرشحات البريد الإلكتروني';
$html_use_graphical_smilies = 'استخدم الابتسامات الرسومية';
$html_colored_quotes = 'اقتباسات ملوّنة';
$html_send_html_mail = 'أرسل البريد بهيئة HTML';
$html_folders = 'مجلدات';
$html_folders_create_failed = 'تعذّر إنشاء المجلد!';
$html_folders_sub_failed = 'تعذّر الاشتراك بالمجلد!';
$html_folders_unsub_failed = 'تعذّر إلغاء الاشتراك من المجلد!';
$html_folders_updated = 'حُدّثت المجلدات';
$html_folder_subscribe = 'اشترك ب';
$html_folder_rename = 'إعادة تسمية';
$html_folder_create = 'أنشئ مجلدا جديدا يسمّى';
$html_folder_remove = 'ألغِ الاشتراك من';
$html_folder_delete = 'حذف';
$html_folder_to = 'إلى';
$html_filter_remove = 'حذف';
$html_filter_body = 'جسم الرسالة';
$html_filter_subject = 'موضوع الرسالة';
$html_filter_to = 'حقل إلى';
$html_filter_cc = 'حقل النسخة';
$html_filter_from = 'حقل من';
$html_filter_change_tip = 'لتغيير مرشّح ببساطة اكتب فوقه.';
$html_reapply_filters = 'أعد تفعيل كل المرشحات';
$html_filter_contains = 'يحتوي على';
$html_filter_name = 'اسم المرشح';
$html_filter_action = 'فعل المرشح';
$html_filter_moveto = 'نقل إلى';
$html_select_one = '--اختر واحدا--';
$html_and = 'و';
$html_new_msg_in = 'الرسائل الجديدة في';
$html_or = 'أو';
$html_move = 'نقل';
$html_copy = 'نسخ';
$html_messages_to = 'الرسالة المختارة إلى';
$html_gotopage = 'اذهب إلى الصفحة';
$html_gotofolder = 'اذهب إلى المجلد';
$html_other_folders = 'قائمة المجلدات';
$html_page = 'صفحة';
$html_of = 'ل';
$html_view_header = 'المقدمة';
$html_remove_header = 'ءاخفاء المقدمة';
$html_inbox = 'صندوق الرسائل';
$html_new_msg = 'رسالة جديدة';
$html_reply = 'ءاجابة';
$html_reply_short = 'رد:';
$html_reply_all = 'ءاجابة للكل';
$html_forward = 'تحويل الرسالة ءالى';
$html_forward_short = 'تحويل:';
$html_delete = 'ءازالة';
$html_new = 'جديد';
$html_mark = 'محو';
$html_att_label = 'مرفق:';
$html_atts_label = 'مرفقات:';
$html_unknown = '[غير معروف]';
$html_attach = 'ءاضافة';
$html_attach_forget = '!يجب ءاضافة الملف قبل ءارسال الرسالة';
$html_attach_delete = 'ءازالة الملفات المختارة';
$html_attach_none = 'يجب أن تختار ملفا للإرفاق!';
$html_sort_by = 'مرتبة حسب';
$html_sort = 'رتب';
$html_from = 'من';
$html_from_label = 'من:';
$html_subject = 'الموضوع';
$html_subject_label = 'الموضوع:';
$html_date = 'التاريخ';
$html_date_label = 'التاريخ:';
$html_sent_label = 'أرسل:';
$html_wrote = 'كتب';
$html_size = 'الحجم';
$html_totalsize = 'الحجم الكلي';
$html_kb = 'كيلوبايت';
$html_mb = 'ميجابايت';
$html_gb = 'جيجابايت';
$html_bytes = 'بايت';
$html_filename = 'ملف';
$html_to = 'ءالى';
$html_to_label = 'إلى:';
$html_cc = 'نسخة';
$html_cc_label = 'سي سي:';
$html_bcc_label = 'بي سي سي:';
$html_nosubject = 'بدون موضوع';
$html_send = 'أرسل';
$html_cancel = 'ألغِ';
$html_no_mail = 'ليست هناك أية رسالة';
$html_logout = 'اخرج';
$html_msg = 'رسالة';
$html_msgs = 'رسائل';
$html_configuration = 'لم يُعد هذا الخادوم بشكل صحيح!';
$html_priority = 'أولوية';
$html_priority_label = 'الأولوية:';
$html_lowest = 'الأقل';
$html_low = 'أقل';
$html_normal = 'عادي';
$html_high = 'أعلى';
$html_highest = 'الأعلى';
$html_flagged = 'معلم';
$html_select = 'اختر';
$html_select_all = 'اعكس الاختيار';
$html_select_contacts = 'اختر مراسلين';
$html_loading_image = 'تحميل الصورة';
$html_error_occurred = 'صودف خطأ';
$html_wrap_none = 'لا لف';
$html_mark_as = 'علّم كـ';
$html_read = 'اقرأ';
$html_unread = 'غير مقروءة';
$html_encoding_label = 'ترميز المحارف:';
$html_add = 'أضف';
$html_contacts = 'معارف %1$s';
$html_modify = 'عدل';
$html_back = 'رجوع';
$html_contact_add = 'أضف مراسلا جديدا';
$html_contact_mod = 'عدّل مراسلا';
$html_contact_first = 'الاسم الأول';
$html_contact_last = 'الاسم الأخير';
$html_contact_nick = 'الكنية';
$html_contact_mail = 'بريد';
$html_contact_list = 'قائمة معارف %1$s';
$html_contact_del = 'من قائمة المراسلين';
$html_contact_err1 = 'أقصى عدد للمراسلين هو "%1$d"';
$html_contact_err2 = 'لا تستطيع إضافة مراسل جديد';
$html_contact_err3 = 'لا تمتلك صلاحيات الوصول إلى قائمة المراسلين';
$html_contact_none = 'تعذّر إيجاد أي مراسلين.';
$html_del_msg = 'أأحذف الرسائل المختارة؟';
$html_down_mail = 'تنزيل';
$original_msg = '--  الرسالة الأصلية  --';
$to_empty = 'يجب ءاعطاء عنوان المرسل ءاليه !';
$html_images_warning = 'لأسباب أمنية، الصور البعيدة غير معروضة.';
$html_images_display = 'اعرض الصور';
$html_smtp_error_no_conn = 'تعذّر فتح اتصال SMTP';
$html_smtp_error_unexpected = 'رد SMTP غير متوقع:';
$lang_could_not_connect = 'لم يمكن الاتصال بالخادم';
$lang_invalid_msg_num = 'عدد الرسائل السيئة';
$html_invalid_email_address = 'عنوان بريد إلكتروني غير صحيح';
$html_invalid_msg_per_page = 'عدد رسائل لكل صفحة غير صحيح';
$lang_err_send_delay = 'يجب أن تنتظر بين البريدين الإلكترونيين (%1$d ثانية)';
$html_search = 'بحث';
